Crate jsonschema_value

Crate jsonschema_value 

JSON value representations and semantics shared by the validator and its bindings.

Modules

cmp
numeric
numeric_check
types
JSON type representations for schema validation.
unique

Structs

NodeIdentity
What tells one node from another within a validation call.
SerdeJson

Traits

Array
Json
One JSON representation.
JsonNumber
A JSON number, readable without constructing a ::serde_json::Number.
Node
One JSON value; Clone must be cheap.
Object