Module types

Module types 

JSON type representations for schema validation.

Provides JsonType for individual types and JsonTypeSet for efficient bitset-based type checking in validation hot paths.

Structs

JsonTypeSet
A set of JSON types.
JsonTypeSetIterator
Iterator for traversing the types in a JsonTypeSet.

Enums

JsonType
Represents a JSON value type.

Functions

number_is_integer
Whether n holds an integer value per drafts 6+ (floats with a zero fractional part count as integers).