pub struct JsonTypeSet(/* private fields */);Expand description
A set of JSON types.
Implementations
Sourceimpl JsonTypeSet
impl JsonTypeSet
Sourcepub const fn insert(self, ty: JsonType) -> Self
pub const fn insert(self, ty: JsonType) -> Self
Add a type to this set and return the modified set.
Sourcepub const fn remove(self, ty: JsonType) -> Self
pub const fn remove(self, ty: JsonType) -> Self
Remove a type from this set and return the modified set.
Sourcepub fn contains_value_type<F: Json>(self, value: &F::Node<'_>) -> bool
pub fn contains_value_type<F: Json>(self, value: &F::Node<'_>) -> bool
Whether a JSON value’s type is allowed by this set.
Sourcepub fn iter(&self) -> JsonTypeSetIterator ⓘ
pub fn iter(&self) -> JsonTypeSetIterator ⓘ
Get an iterator over the types in this set.