JSON value representations and semantics shared by the validator and its bindings.
Modules
- cmp
- numeric
- numeric_
check - types
- JSON type representations for schema validation.
- unique
Structs
- Node
Identity - What tells one node from another within a validation call.
- Serde
Json
Traits
- Array
- Json
- One JSON representation.
- Json
Number - A JSON number, readable without constructing a
::serde_json::Number. - Node
- One JSON value;
Clonemust be cheap. - Object