Crate jsonschema_value

Crate jsonschema_value 

JSON value representations and semantics shared by the validator and its bindings.

Modules

ext
types
JSON type representations for schema validation.

Structs

SerdeJson

Traits

Json
Ties together the concrete node types for one JSON representation.
JsonArrayAccess
JsonNode
One JSON value in some concrete representation; Clone must be cheap (borrow, refcount bump, or machine word copy).
JsonObjectAccess