JSON value representations and semantics shared by the validator and its bindings.
Modules
Structs
Traits
- Json
- Ties together the concrete node types for one JSON representation.
- Json
Array Access - Json
Node - One JSON value in some concrete representation;
Clonemust be cheap (borrow, refcount bump, or machine word copy). - Json
Object Access