pub trait Json:
Sized
+ Send
+ Sync
+ 'static {
type Node<'a>: JsonNode<'a, Self>;
type PreparedKey: Send + Sync;
// Required method
fn prepare_key(key: &str) -> Self::PreparedKey;
}Expand description
Ties together the concrete node types for one JSON representation.
Required Associated Types
type Node<'a>: JsonNode<'a, Self>
Sourcetype PreparedKey: Send + Sync
type PreparedKey: Send + Sync
A property-name key prepared once at schema compile time for repeated object lookups.
Required Methods
fn prepare_key(key: &str) -> Self::PreparedKey
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".